<?php

namespace Bixo\Contact\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bixo\Contact\Http\Requests\AccountsRequest;
use Bixo\Contact\Models\Accounts;

/**
 * Admin web controller class.
 */
class AccountsWorkflowController extends BaseController
{

    /**
     * Workflow controller function for accounts.
     *
     * @param Model   $accounts
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AccountsRequest $request, Accounts $accounts, $step)
    {

        try {

            $accounts->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('contact::accounts.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/accounts/accounts/' . $accounts->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/accounts/accounts/' . $accounts->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for accounts.
     *
     * @param Model   $accounts
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Accounts $accounts, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $accounts->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('contact::accounts.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('contact::admin.accounts.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('contact::admin.accounts.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('contact::admin.accounts.message', $data)->render();

        }

    }
}
