<?php

namespace Bixo\Contact\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Bixo\Contact\Models\Accounts;

class AccountsAction
{
    /**
     * Perform the complete action.
     *
     * @param Accounts $accounts
     *
     * @return Accounts
     */
    public function complete(Accounts $accounts)
    {
        try {
            $accounts->status = 'complete';
            return $accounts->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Accounts $accounts
     *
     * @return Accounts
     */public function verify(Accounts $accounts)
    {
        try {
            $accounts->status = 'verify';
            return $accounts->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Accounts $accounts
     *
     * @return Accounts
     */public function approve(Accounts $accounts)
    {
        try {
            $accounts->status = 'approve';
            return $accounts->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Accounts $accounts
     *
     * @return Accounts
     */public function publish(Accounts $accounts)
    {
        try {
            $accounts->status = 'publish';
            return $accounts->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Accounts $accounts
     *
     * @return Accounts
     */
    public function archive(Accounts $accounts)
    {
        try {
            $accounts->status = 'archive';
            return $accounts->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Accounts $accounts
     *
     * @return Accounts
     */
    public function unpublish(Accounts $accounts)
    {
        try {
            $accounts->status = 'unpublish';
            return $accounts->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
