<?php

namespace Bixo\Contact\Workflow;

use Bixo\Contact\Models\Accounts;
use Validator;

class AccountsValidator
{

    /**
     * Determine if the given accounts is valid for complete status.
     *
     * @param Accounts $accounts
     *
     * @return bool / Validator
     */
    public function complete(Accounts $accounts)
    {
        return Validator::make($accounts->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given accounts is valid for verify status.
     *
     * @param Accounts $accounts
     *
     * @return bool / Validator
     */
    public function verify(Accounts $accounts)
    {
        return Validator::make($accounts->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given accounts is valid for approve status.
     *
     * @param Accounts $accounts
     *
     * @return bool / Validator
     */
    public function approve(Accounts $accounts)
    {
        return Validator::make($accounts->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given accounts is valid for publish status.
     *
     * @param Accounts $accounts
     *
     * @return bool / Validator
     */
    public function publish(Accounts $accounts)
    {
        return Validator::make($accounts->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given accounts is valid for archive status.
     *
     * @param Accounts $accounts
     *
     * @return bool / Validator
     */
    public function archive(Accounts $accounts)
    {
        return Validator::make($accounts->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given accounts is valid for unpublish status.
     *
     * @param Accounts $accounts
     *
     * @return bool / Validator
     */
    public function unpublish(Accounts $accounts)
    {
        return Validator::make($accounts->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
